@@ -8,10 +8,32 @@ import tifffile as tiff
 from skimage.transform import resize
 from sklearn.preprocessing import minmax_scale
 
-from unetseg.train import build_data_generator
+from unetseg.predict import PredictConfig
+from unetseg.train import TrainConfig, build_data_generator
 
 
-def plot_data_generator(num_samples=3, fig_size=(20, 10), *, train_config, img_ch=3):
+def plot_data_generator(
+    num_samples: int = 3,
+    fig_size=(20, 10),
+    *,
+    train_config: TrainConfig,
+    img_ch: int = 3
+):
+    """
+    Plots some samples from a data generator.
+
+    Parameters
+    ----------
+    num_samples : int
+        Number of samples to plot.
+    fig_size : tuple
+        Figure size.
+    img_ch : int
+        Number of channels.
+    train_config : TrainConfig
+        Training configuration object.
+
+    """
 
     if train_config.n_channels < 4:
         img_ch = train_config.n_channels
@@ -35,7 +57,11 @@ def plot_data_generator(num_samples=3, fig_size=(20, 10), *, train_config, img_c
                     nrows=1, ncols=train_config.n_classes + 1, figsize=fig_size
                 )
 
-                image = image[:, :, :img_ch].astype(np.uint8)
+                if train_config.n_channels < 4:
+                    image = image[:, :, 0].astype(np.uint8)
+                else:
+                    image = image[:, :, :img_ch].astype(np.uint8)
+
                 ax[0].imshow(image)
                 for i in range(train_config.n_classes):
                     ax[i + 1].imshow(mask[:, :, i])
@@ -47,12 +73,28 @@ def plot_data_generator(num_samples=3, fig_size=(20, 10), *, train_config, img_c
     plt.show()
 
 
-def plot_data_results(num_samples=3, fig_size=(20, 10), *, predict_config, img_ch=3):
+def plot_data_results(
+    num_samples: int = 3,
+    fig_size=(20, 10),
+    *,
+    predict_config: PredictConfig,
+    img_ch: int = 3
+):
+    """
+    Plots some samples from the results directory.
 
-    if predict_config.n_channels < 4:
-        img_ch = predict_config.n_channels
-    else:
-        img_ch = img_ch
+    Parameters
+    ----------
+    num_samples : int
+        Number of samples to plot.
+    fig_size : tuple
+        Figure size.
+    img_ch : int
+        Number of channels.
+    predict_config : PredictConfig
+        Prediction onfiguration object.
+
+    """
 
     images = [
         os.path.basename(f)
@@ -62,18 +104,32 @@ def plot_data_results(num_samples=3, fig_size=(20, 10), *, predict_config, img_c
     images = random.sample(images, num_samples)
     for img_file in images:
         try:
-            # s2 3D
-            img_s2 = tiff.imread(
-                os.path.join(predict_config.images_path, "images", img_file)
-            )[:, :, :img_ch]
-            img_s2 = minmax_scale(img_s2.ravel(), feature_range=(0, 255)).reshape(
-                img_s2.shape
-            )
+
+            if predict_config.n_channels < 3:
+
+                img_s2 = tiff.imread(
+                    os.path.join(predict_config.images_path, "images", img_file)
+                )
+
+                img_s2 = minmax_scale(img_s2.ravel(), feature_range=(0, 255)).reshape(
+                    img_s2.shape
+                )
+
+            else:
+                img_s2 = tiff.imread(
+                    os.path.join(predict_config.images_path, "images", img_file)
+                )[:, :, :img_ch]
+
+                img_s2 = minmax_scale(img_s2.ravel(), feature_range=(0, 255)).reshape(
+                    img_s2.shape
+                )
 
             # Prediccion
             mask_ = (
                 tiff.imread(os.path.join(predict_config.results_path, img_file)) / 255
             )
+            mask_ = np.rollaxis(mask_, 0, 3)
+
             mask_ = resize(
                 mask_,
                 (predict_config.height, predict_config.width, predict_config.n_classes),
@@ -84,10 +140,8 @@ def plot_data_results(num_samples=3, fig_size=(20, 10), *, predict_config, img_c
             fig, axes = plt.subplots(
                 nrows=1, ncols=predict_config.n_classes + 1, figsize=(20, 40)
             )
-
-            img_s2 = img_s2.astype(np.uint8)
-
             axes[0].imshow(img_s2)
+
             for c in range(predict_config.n_classes):
                 axes[1 + c].imshow(np.squeeze(mask_[:, :, c]))
 
